#
# spec file for package python-zeep
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-zeep
Version:        4.2.1
Release:        1.2
Summary:        A Python SOAP client based on lxml/requests
License:        MIT
URL:            http://docs.python-zeep.org
Source:         https://files.pythonhosted.org/packages/source/z/zeep/zeep-%{version}.tar.gz
# PATCH-FIX-OPENSUSE xfail tests that require network access
Patch0:         xfail-network-tests.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 17.2.0
Requires:       python-cached-property >= 1.3.0
Requires:       python-isodate >= 0.5.4
Requires:       python-lxml >= 4.6.0
Requires:       python-platformdirs >= 1.4.0
Requires:       python-pytz
Requires:       python-requests >= 2.7.0
Requires:       python-requests-file >= 1.5.1
Requires:       python-requests-toolbelt >= 0.7.1
Recommends:     python-xmlsec >= 0.6.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module platformdirs >= 1.4.0}
BuildRequires:  %{python_module aiohttp >= 1.0}
BuildRequires:  %{python_module aioresponses >= 0.4.1}
BuildRequires:  %{python_module attrs >= 17.2.0}
BuildRequires:  %{python_module cached-property >= 1.3.0}
BuildRequires:  %{python_module freezegun >= 0.3.15}
BuildRequires:  %{python_module isodate >= 0.5.4}
BuildRequires:  %{python_module lxml >= 4.6.0}
BuildRequires:  %{python_module pretend >= 1.0.9}
BuildRequires:  %{python_module pytest >= 6.0.1}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-httpx}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module requests >= 2.7.0}
BuildRequires:  %{python_module requests-file >= 1.5.1}
BuildRequires:  %{python_module requests-mock >= 0.7.0}
BuildRequires:  %{python_module requests-toolbelt >= 0.7.1}
BuildRequires:  %{python_module xmlsec >= 0.6.1}
BuildRequires:  libxmlsec1-openssl1
# /SECTION
%python_subpackages

%description
Python SOAP client based on python-lxml and python-requests

%prep
%autosetup -p1 -n zeep-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%pytest tests

%files %{python_files}
%doc CHANGES README.rst
%license LICENSE
%{python_sitelib}/zeep
%{python_sitelib}/zeep-%{version}.dist-info

%changelog
* Fri Dec 15 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.2.1:
  * Fix error regarding closing session in async transport (#1347)
  * Drop support for Python 3.6
  * Allow embedding CDATA elements in simple types (#1339)
  * Allow to pass in a pre parsed Document (#1330)
  * Fix httpx DeprecationWarning for post data (#1326)
  * Add BinaryMemorySignature (#1300)
  * Fix IndexError when empty body response (#1287)
  * Add support for context manager on Client (#1166)
  * Allow Ws Addressing plugin to use a different URL (#1328)
  * Accept strings for xsd base64Binary (#1072)
- Drop patches httpx-test.patch, python-zeep-no-mock.patch:
  * Included upstream.
- Add patch xfail-network-tests.patch:
  * XFAIL, rather than FAIL tests that require a network connection.
- Switch to autosetup and pyproject macros.
- BuildRequire xmlsec unilaterally and install the openssl library.
- No longer ignore some test files
* Wed Jun  8 2022 Ben Greiner <code@bnavigator.de>
- Re-enable python310: xmlsec is optional
- Disable python2 build
* Sat May 21 2022 Matej Cepl <mcepl@suse.com>
- Doesn't build with 3.10 because of missing xmlsec.
* Thu Apr 14 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/mvantellingen/python-zeep/commit/1ddd118956870f9c68a24c9494207dc17441b416
  + python-zeep-no-mock.patch
* Sun Mar 13 2022 Wolfgang Rosenauer <wr@rosenauer.org>
- Update to 4.1.0
  * Remove last dependency on six
  * Use platformdirs instead of the appsdirs dependency
  * Pass digest method when signing timestamp node
  * Fix settings context manager when an exception is raised
  * Don’t render decimals using scientific notation
  * Remove dependency on defusedxml
  * Improve handling of str values for Duration
- added httpx-test.patch to use text instead of data
* Thu Jun  3 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 4.0.0
  * Drop support for Python 2.7, 3.3, 3.4 and 3.5
  * Remove both the aiohttp and the tornado transport class from
    Zeep. These can be moved to their own Python package if anyone
    is interested.
  * Add zeep.transports.AsyncTransport which is based on httpx.
    Note that loading wsdl files is still a sync process but
    operations can be executed via async.
  * Start adding more typehints to the package
- Remove patches that are not needed anymore:
  * pytest4.patch
  * pytest5.patch
* Fri Apr 16 2021 Ben Greiner <code@bnavigator.de>
- Fix BuildRequires for new python39 flavor
- Disable tests using python2 freezegun
* Fri Jan 22 2021 Benjamin Greiner <code@bnavigator.de>
- Fix typo in filelist
* Tue Jan 19 2021 Benjamin Greiner <code@bnavigator.de>
- Fix requirement specifications.
* Fri Nov  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patches to fix build with current pytests (From upstream PRs):
  * pytest4.patch
  * pytest5.patch
- Tweak the deps to stay resolvable
* Mon Aug 26 2019 Todd R <toddrme2178@gmail.com>
- Fix unit tests
- Use better way to handle tornado version compatibility.
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Don't allow python-tornado >= 5
* Fri Jun 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.4.0
  * Allow passing xsd.Nil to sequences
  * Add support for passing custom digest and signature methods during WSSE
    signing
  * Fix path resolving during XSD imports
* Mon Mar 25 2019 pgajdos@suse.com
- version update to 3.3.1
  * Fix issue with empty xsd:import statements on Python 2.7 (#930)
  * Extend the force_https flag to also force loading xsd files from https when
  a http url is encountered from a https domain
  * Fix handling recursive xsd imports when the url's are enforced from http to
  https.
  * Fix reference attribute when using the Binary Security Token (#873)
  * Add support for the WSAM namespace (#890)
* Tue Feb 26 2019 John Vandenberg <jayvdb@gmail.com>
- Remove from builds undesirable pytest plugins suited for development
- Add minimum build version for tornado
- Remove inappropriate runtime dependency on aioresponses
- Update to v3.2.0
  * Fix abstract message check for NoneType before attempting to access parts
  * Improve support for 'Chameleon' XSD schemas (#879, #888)
  * Fix resolving qualified references (#879)
  * Fix issue with duplicate soap:body tags when multiple parts used (#879)
  * Fix Choice with unbound Any element (#871)
  * Add xsd_ignore_sequence_order flag (#880)
  * Add support for timestamp token in WSS headers (#817)
  * Accept strings for xsd.DateTime (#886)
* Fri Dec  7 2018 Tomáš Chvátal <tchvatal@suse.com>
- Drop patch relax-python-requires.patch not really needed
- Try to check mtime issue on pyc files
  * caused by fdupes as it is linking equal file with diferent mtime
    while it should have no real impact on the package
* Tue Nov 27 2018 Jan Engelhardt <jengelh@inai.de>
- Trim time-sensitive wording of summary.
* Tue Nov 27 2018 Tomáš Chvátal <tchvatal@suse.com>
- Sort out with spec-cleaner
- Remove not needed devel dependency
* Mon Nov 26 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 3.1.0
- Add patch to relax Python version requirements in setup.py
  + relax-python-requires.patch
- Disable tests that are currently broken
  + tests/test_tornado_transport.py
  + tests/test_wsse_signature.py
  + tests/test_wsse_username.py
  + tests/test_wsse_utils.py
